# cloud-oauth
[![Latest Version](https://img.shields.io/pypi/v/inovonics-cloud-oauth.svg)](https://pypi.python.org/pypi/inovonics-cloud-oauth)
[![Build Status](https://travis-ci.org/inovonics/cloud-oauth.svg?branch=master)](https://travis-ci.org/inovonics/cloud-oauth)
[![Coverage Status](https://coveralls.io/repos/github/inovonics/cloud-oauth/badge.svg?branch=master)](https://coveralls.io/github/inovonics/cloud-oauth?branch=master)

Classes implementing functionality for flask-oauthlib using Redis as the backing store.

Install via PyPI: `pip3 install inovonics-cloud-oauth`

or install straight from github: `pip3 install git+https://github.com/inovonics/cloud-oauth.git`
